@@ -49,9 +49,9 @@ decorate.elmNN = function(x, data, ...){
 #' library("r2pmml")
 #'
 #' data(iris)
-#' iris_x = as.matrix(iris[, -ncol(iris)])
+#' iris_X = as.matrix(iris[, -ncol(iris)])
 #' iris_y = iris[, ncol(iris)]
-#' iris.glmnet = glmnet(x = iris_x, y = iris_y, family = "multinomial")
+#' iris.glmnet = glmnet(x = iris_X, y = iris_y, family = "multinomial")
 #' iris.glmnet = decorate(iris.glmnet, lambda.s = iris.glmnet$lambda[49])
 #' r2pmml(iris.glmnet, file.path(tempdir(), "Iris-GLMNet.pmml"))
 #' }
@@ -154,7 +154,25 @@ decorate.svm.formula = function(x, data, ...){
 decorate.train = function(x, ...){
 	x$finalModel = decorate(x$finalModel, preProcess = NULL, ...)
 
-	return (x)
+	return(x)
+}
+
+#' Decorates a "WrappedModel" object with "invert_levels" element.
+#' Additionally, decorates the learned model with model type-dependent elements.
+#'
+#' @param x A "WrappedModel" object.
+#' @param invert_levels A flag indicating if the learned model should assume normal (FALSE) or inverted (TRUE) ordering of category values for the binary categorical target field.
+#' @param ... Arguments to pass on to the "decorate.default" function
+decorate.WrappedModel = function(x, invert_levels = FALSE, ...){
+	task.desc = x$task.desc
+
+	if(task.desc$type == "classif" && length(task.desc$class.levels) == 2){
+		x$invert_levels = invert_levels
+	}
+
+	x$learner.model = decorate(x$learner.model, ...)
+
+	return(x)
 }
 
 #' Decorates an "xgb.Booster" object with "fmap", "schema", "ntreelimit" and "pmml_options" elements.
@@ -174,13 +192,14 @@ decorate.train = function(x, ...){
 #' library("r2pmml")
 #'
 #' data(iris)
-#' iris_x = iris[, -ncol(iris)]
+#' iris_X = iris[, -ncol(iris)]
 #' iris_y = iris[, ncol(iris)]
 #' # Convert from factor to integer[0, num_class]
 #' iris_y = (as.integer(iris_y) - 1)
-#' iris.fmap = genFMap(iris_x)
-#' iris.dmatrix = genDMatrix(iris_y, iris_x)
-#' iris.xgboost = xgboost(data = iris.dmatrix, 
+#' iris.matrix = model.matrix(~ . - 1, data = iris_X)
+#' iris.DMatrix = xgb.DMatrix(iris.matrix, label = iris_y)
+#' iris.fmap = as.fmap(iris.matrix)
+#' iris.xgboost = xgboost(data = iris.DMatrix,
 #'     objective = "multi:softprob", num_class = 3, nrounds = 11)
 #' iris.xgboost = decorate(iris.xgboost, iris.fmap, 
 #'     response_name = "Species", response_levels = c("setosa", "versicolor", "virginica"))
@@ -238,11 +257,11 @@ decorate.default = function(x, preProcess = NULL, pmml_options = NULL, ...){
 		x$pmml_options = pmml_options
 	}
 
-	return (x)
+	return(x)
 }
 
 .getFactorLevels = function(data){
 	levels = lapply(data, function(x){ if(is.factor(x)) { levels(x) } else { NULL }})
 
-	return (levels[!vapply(levels, is.null, NA)])
+	return(levels[!vapply(levels, is.null, NA)])
 }
