@@ -18,7 +18,7 @@
  */
 package org.jpmml.converter.visitors;
 
-import org.jpmml.model.VisitorBattery;
+import org.jpmml.model.visitors.VisitorBattery;
 
 public class ModelCleanerBattery extends VisitorBattery {
 
@@ -27,6 +27,7 @@ public class ModelCleanerBattery extends VisitorBattery {
 		add(TransformationDictionaryCleaner.class);
 		add(DerivedFieldRelocator.class);
 		add(DataDictionaryCleaner.class);
+		add(FunctionDictionaryCleaner.class);
 
 		// OutputField elements
 		add(DerivedOutputFieldTransformer.class);
