@@ -42,7 +42,7 @@ import org.jpmml.converter.Feature;
 import org.jpmml.converter.HasDerivedName;
 import org.jpmml.converter.InteractionFeature;
 import org.jpmml.converter.PowerFeature;
-import org.jpmml.model.ValueUtil;
+import org.jpmml.converter.ValueUtil;
 
 public class Formula {
 
@@ -125,7 +125,7 @@ public class Formula {
 					Constant constant = (Constant)expressions.get(1);
 
 					try {
-						String string = ValueUtil.toString(constant.getValue());
+						String string = ValueUtil.asString(constant.getValue());
 
 						int power = Integer.parseInt(string);
 
