@@ -45,6 +45,7 @@ import org.jpmml.converter.CategoryManager;
 import org.jpmml.converter.ContinuousFeature;
 import org.jpmml.converter.ContinuousLabel;
 import org.jpmml.converter.Feature;
+import org.jpmml.converter.FieldNameUtil;
 import org.jpmml.converter.FlagManager;
 import org.jpmml.converter.ModelUtil;
 import org.jpmml.converter.Schema;
@@ -108,7 +109,7 @@ public class GBMConverter extends TreeModelConverter<RGenericVector> {
 
 			boolean categorical = (ValueUtil.asInt(var_type.getValue(i)) > 0);
 			if(categorical){
-				RStringVector var_level = (RStringVector)var_levels.getValue(i);
+				RStringVector var_level = var_levels.getStringValue(i);
 
 				dataField = encoder.createDataField(varName, OpType.CATEGORICAL, DataType.STRING, var_level.getValues());
 			} else
@@ -137,7 +138,7 @@ public class GBMConverter extends TreeModelConverter<RGenericVector> {
 		List<TreeModel> treeModels = new ArrayList<>();
 
 		for(int i = 0; i < trees.size(); i++){
-			RGenericVector tree = (RGenericVector)trees.getValue(i);
+			RGenericVector tree = trees.getGenericValue(i);
 
 			TreeModel treeModel = encodeTreeModel(MiningFunction.REGRESSION, tree, c_splits, segmentSchema);
 
@@ -189,7 +190,7 @@ public class GBMConverter extends TreeModelConverter<RGenericVector> {
 
 		for(int i = 0, columns = categoricalLabel.size(), rows = (treeModels.size() / columns); i < columns; i++){
 			MiningModel miningModel = createMiningModel(CMatrixUtil.getColumn(treeModels, rows, columns, i), initF, segmentSchema)
-				.setOutput(ModelUtil.createPredictedOutput(FieldName.create("gbmValue(" + categoricalLabel.getValue(i) + ")"), OpType.CONTINUOUS, DataType.DOUBLE));
+				.setOutput(ModelUtil.createPredictedOutput(FieldNameUtil.create("gbmValue", categoricalLabel.getValue(i)), OpType.CONTINUOUS, DataType.DOUBLE));
 
 			miningModels.add(miningModel);
 		}
@@ -198,7 +199,7 @@ public class GBMConverter extends TreeModelConverter<RGenericVector> {
 	}
 
 	private TreeModel encodeTreeModel(MiningFunction miningFunction, RGenericVector tree, RGenericVector c_splits, Schema schema){
-		Node root = encodeNode(True.INSTANCE, 0, tree, c_splits, new FlagManager(), new CategoryManager(), schema);
+		Node root = encodeNode(0, True.INSTANCE, tree, c_splits, new FlagManager(), new CategoryManager(), schema);
 
 		TreeModel treeModel = new TreeModel(miningFunction, ModelUtil.createMiningSchema(schema.getLabel()), root)
 			.setSplitCharacteristic(TreeModel.SplitCharacteristic.MULTI_SPLIT);
@@ -206,16 +207,16 @@ public class GBMConverter extends TreeModelConverter<RGenericVector> {
 		return treeModel;
 	}
 
-	private Node encodeNode(Predicate predicate, int i, RGenericVector tree, RGenericVector c_splits, FlagManager flagManager, CategoryManager categoryManager, Schema schema){
-		RIntegerVector splitVar = (RIntegerVector)tree.getValue(0);
-		RDoubleVector splitCodePred = (RDoubleVector)tree.getValue(1);
-		RIntegerVector leftNode = (RIntegerVector)tree.getValue(2);
-		RIntegerVector rightNode = (RIntegerVector)tree.getValue(3);
-		RIntegerVector missingNode = (RIntegerVector)tree.getValue(4);
-		RDoubleVector prediction = (RDoubleVector)tree.getValue(7);
-
+	private Node encodeNode(int i, Predicate predicate, RGenericVector tree, RGenericVector c_splits, FlagManager flagManager, CategoryManager categoryManager, Schema schema){
 		Integer id = Integer.valueOf(i + 1);
 
+		RIntegerVector splitVar = tree.getIntegerValue(0);
+		RDoubleVector splitCodePred = tree.getDoubleValue(1);
+		RIntegerVector leftNode = tree.getIntegerValue(2);
+		RIntegerVector rightNode = tree.getIntegerValue(3);
+		RIntegerVector missingNode = tree.getIntegerValue(4);
+		RDoubleVector prediction = tree.getDoubleValue(7);
+
 		Integer var = splitVar.getValue(i);
 		if(var == -1){
 			Double value = prediction.getValue(i);
@@ -263,7 +264,7 @@ public class GBMConverter extends TreeModelConverter<RGenericVector> {
 
 			int index = ValueUtil.asInt(split);
 
-			RIntegerVector c_split = (RIntegerVector)c_splits.getValue(index);
+			RIntegerVector c_split = c_splits.getIntegerValue(index);
 
 			List<Integer> splitValues = c_split.getValues();
 
@@ -275,8 +276,8 @@ public class GBMConverter extends TreeModelConverter<RGenericVector> {
 			leftCategoryManager = leftCategoryManager.fork(name, leftValues);
 			rightCategoryManager = rightCategoryManager.fork(name, rightValues);
 
-			leftPredicate = createSimpleSetPredicate(categoricalFeature, leftValues);
-			rightPredicate = createSimpleSetPredicate(categoricalFeature, rightValues);
+			leftPredicate = createPredicate(categoricalFeature, leftValues);
+			rightPredicate = createPredicate(categoricalFeature, rightValues);
 		} else
 
 		{
@@ -293,21 +294,21 @@ public class GBMConverter extends TreeModelConverter<RGenericVector> {
 
 		Integer missing = missingNode.getValue(i);
 		if(missing != -1 && (isMissing == null || isMissing)){
-			Node missingChild = encodeNode(missingPredicate, missing, tree, c_splits, missingFlagManager, categoryManager, schema);
+			Node missingChild = encodeNode(missing, missingPredicate, tree, c_splits, missingFlagManager, categoryManager, schema);
 
 			nodes.add(missingChild);
 		}
 
 		Integer left = leftNode.getValue(i);
 		if(left != -1 && (isMissing == null || !isMissing)){
-			Node leftChild = encodeNode(leftPredicate, left, tree, c_splits, nonMissingFlagManager, leftCategoryManager, schema);
+			Node leftChild = encodeNode(left, leftPredicate, tree, c_splits, nonMissingFlagManager, leftCategoryManager, schema);
 
 			nodes.add(leftChild);
 		}
 
 		Integer right = rightNode.getValue(i);
 		if(right != -1 && (isMissing == null || !isMissing)){
-			Node rightChild = encodeNode(rightPredicate, right, tree, c_splits, nonMissingFlagManager, rightCategoryManager, schema);
+			Node rightChild = encodeNode(right, rightPredicate, tree, c_splits, nonMissingFlagManager, rightCategoryManager, schema);
 
 			nodes.add(rightChild);
 		}
